@@ -1,4 +1,4 @@
 ( cd lib ; rm -rf libdm.so.0 )
 ( cd lib ; ln -sf libdm.so.0.0.4 libdm.so.0 )
 ( cd usr/lib ; rm -rf libdm.so )
-( cd usr/lib ; ln -sf ../../lib/libdm.so.0 libdm.so )
+( cd usr/lib ; ln -sf /lib/libdm.so.0 libdm.so )
